Struct diem_sdk::crypto::multi_ed25519::MultiEd25519Signature [−][src]
pub struct MultiEd25519Signature { /* fields omitted */ }Expand description
Vector of the multi-key signatures along with a 32bit [u8; 4] bitmap required to map signatures with their corresponding public keys.
Note that bits are read from left to right. For instance, in the following bitmap [0b0001_0000, 0b0000_0000, 0b0000_0000, 0b0000_0001], the 3rd and 31st positions are set.
Implementations
pub fn new(
signatures: Vec<(Ed25519Signature, u8), Global>
) -> Result<MultiEd25519Signature, CryptoMaterialError>
pub fn new(
signatures: Vec<(Ed25519Signature, u8), Global>
) -> Result<MultiEd25519Signature, CryptoMaterialError>
This method will also sort signatures based on index.
pub fn new_with_signatures_and_bitmap(
signatures: Vec<Ed25519Signature, Global>,
bitmap: [u8; 4]
) -> MultiEd25519Signature
pub fn new_with_signatures_and_bitmap(
signatures: Vec<Ed25519Signature, Global>,
bitmap: [u8; 4]
) -> MultiEd25519Signature
Creates a new MultiEd25519signature by given signatures and bitmap.
Getter signatures.